=============================
PyDy Package's documentation!
=============================

This is the central page for all PyDy's Documentation.

.. include:: ../README.rst

system module
=============

.. toctree::
   :maxdepth: 2

   system.rst

models module
=============

.. toctree::
   :maxdepth: 1

   models.rst

codegen package
===============

.. toctree::
    :maxdepth: 2

    codegen/codegen.rst
    codegen/api.rst

viz package
===========

.. toctree::
    :maxdepth: 2

    viz/viz.rst
    viz/using_visualizer.rst
    viz/api.rst

Tutorials
=========

.. toctree::
    :maxdepth: 2

    tutorials/beginners.rst
    tutorials/advanced.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
